# generated by datamodel-codegen:
#   filename:  output.json
#   timestamp: 2024-10-25T08:14:34+00:00

from __future__ import annotations

from enum import Enum
from typing import List, Optional

from pydantic import BaseModel, Field, RootModel


class ClassificationOutput(BaseModel):
    label: str = Field(..., description="The predicted class label.")
    score: float = Field(..., description="The corresponding probability.")


class ClassificationOutputTransform(Enum):
    sigmoid = "sigmoid"
    softmax = "softmax"
    none = "none"


class EarlyStopping(Enum):
    never = "never"
    bool_True = True
    bool_False = False


class GenerationParameters(BaseModel):
    temperature: Optional[float] = Field(None, description="The value used to modulate the next token probabilities.")
    top_k: Optional[int] = Field(
        None,
        description="The number of highest probability vocabulary tokens to keep for top-k-filtering.",
    )
    top_p: Optional[float] = Field(
        None,
        description="If set to float < 1, only the smallest set of most probable tokens with probabilities that add up to top_p or higher are kept for generation.",
    )
    typical_p: Optional[float] = Field(
        None,
        description=" Local typicality measures how similar the conditional probability of predicting a target token next is to the expected conditional probability of predicting a random token next, given the partial text already generated. If set to float < 1, the smallest set of the most locally typical tokens with probabilities that add up to typical_p or higher are kept for generation. See [this paper](https://hf.co/papers/2202.00666) for more details.",
    )
    epsilon_cutoff: Optional[float] = Field(
        None,
        description="If set to float strictly between 0 and 1, only tokens with a conditional probability greater than epsilon_cutoff will be sampled. In the paper, suggested values range from 3e-4 to 9e-4, depending on the size of the model. See [Truncation Sampling as Language Model Desmoothing](https://hf.co/papers/2210.15191) for more details.",
    )
    eta_cutoff: Optional[float] = Field(
        None,
        description="Eta sampling is a hybrid of locally typical sampling and epsilon sampling. If set to float strictly between 0 and 1, a token is only considered if it is greater than either eta_cutoff or sqrt(eta_cutoff) * exp(-entropy(softmax(next_token_logits))). The latter term is intuitively the expected next token probability, scaled by sqrt(eta_cutoff). In the paper, suggested values range from 3e-4 to 2e-3, depending on the size of the model. See [Truncation Sampling as Language Model Desmoothing](https://hf.co/papers/2210.15191) for more details.",
    )
    max_length: Optional[int] = Field(
        None,
        description="The maximum length (in tokens) of the generated text, including the input.",
    )
    max_new_tokens: Optional[int] = Field(
        None,
        description="The maximum number of tokens to generate. Takes precedence over maxLength.",
    )
    min_length: Optional[int] = Field(
        None,
        description="The minimum length (in tokens) of the generated text, including the input.",
    )
    min_new_tokens: Optional[int] = Field(
        None,
        description="The minimum number of tokens to generate. Takes precedence over maxLength.",
    )
    do_sample: Optional[bool] = Field(
        None,
        description="Whether to use sampling instead of greedy decoding when generating new tokens.",
    )
    early_stopping: Optional[EarlyStopping] = Field(
        None, description="Controls the stopping condition for beam-based methods."
    )
    num_beams: Optional[int] = Field(None, description="Number of beams to use for beam search.")
    num_beam_groups: Optional[int] = Field(
        None,
        description="Number of groups to divide num_beams into in order to ensure diversity among different groups of beams. See [this paper](https://hf.co/papers/1610.02424) for more details.",
    )
    penalty_alpha: Optional[float] = Field(
        None,
        description="The value balances the model confidence and the degeneration penalty in contrastive search decoding.",
    )
    use_cache: Optional[bool] = Field(
        None,
        description="Whether the model should use the past last key/values attentions to speed up decoding",
    )


class ZeroShotImageClassificationOutput(RootModel[List[ClassificationOutput]]):
    root: List[ClassificationOutput] = Field(
        ...,
        description="Outputs of inference for the Zero Shot Image Classification task",
        title="ZeroShotImageClassificationOutput",
    )
